getwd()
setwd("~/git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts/plotting")
getwd()

########################################################################
# 				Installing and loading required packages 			   #
########################################################################

source("../Header_TT.R")
#source("barplot_colour_function.R")
require(cowplot)

########################################################################
#		 Read file: call script for combining df for PS			   	   #
########################################################################

source("../combining_two_df.R")

#---------------------- PAY ATTENTION
# the above changes the working dir
#[1] "git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts"
#---------------------- PAY ATTENTION

#==========================
# This will return:

# df with NA:
# merged_df2
# merged_df3

# df without NA:
# merged_df2_comp
# merged_df3_comp
#===========================

###########################
# Data for OR and stability plots
# you need merged_df3_comp
# since these are matched 
# to allow pairwise corr
###########################

# uncomment as necessary
#<<<<<<<<<<<<<<<<<<<<<<<<<
# REASSIGNMENT
my_df  = merged_df3_comp
#my_df = merged_df3
#<<<<<<<<<<<<<<<<<<<<<<<<<

# delete variables not required
rm(merged_df2, merged_df2_comp, merged_df3, merged_df3_comp)

# quick checks
colnames(my_df)
str(my_df)

# sanity check
# Ensure correct data type in columns to plot: need to be factor
is.numeric(my_df$OR)
#[1] TRUE

#<<<<<<<<<<<<<<<<<<<
# REASSIGNMENT
# FOR PS Plots
#<<<<<<<<<<<<<<<<<<<

PS_df  = my_df

rm(my_df)
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> end of section 1

########################################################################
#		 Read file: call script for combining df for lig		   	   #
########################################################################

getwd()

source("combining_two_df_lig.R")

#---------------------- PAY ATTENTION
# the above changes the working dir
#[1] "git/LSHTM_analysis/mcsm_analysis/pyrazinamide/scripts"
#---------------------- PAY ATTENTION
#==========================
# This will return:

# df with NA:
# merged_df2
# merged_df3

# df without NA:
# merged_df2_comp
# merged_df3_comp
#===========================

###########################
# Data for OR and stability plots
# you need merged_df3_comp
# since these are matched 
# to allow pairwise corr
###########################

# uncomment as necessary
#<<<<<<<<<<<<<<<<<<<<<<<<<
# REASSIGNMENT
my_df2  = merged_df3_comp
#my_df2 = merged_df3
#<<<<<<<<<<<<<<<<<<<<<<<<<

# delete variables not required
rm(merged_df2, merged_df2_comp, merged_df3, merged_df3_comp)

# quick checks
colnames(my_df2)
str(my_df2)

# sanity check
# Ensure correct data type in columns to plot: need to be factor
is.numeric(my_df2$OR)
#[1] TRUE

# sanity check: should be <10
if (max(my_df2$Dis_lig_Ang) < 10){
  print ("Sanity check passed: lig data is <10Ang")
}else{
  print ("Error: data should be filtered to be within 10Ang")
}

#<<<<<<<<<<<<<<<<
# REASSIGNMENT
# FOR Lig Plots
#<<<<<<<<<<<<<<<<

Lig_df  = my_df2

rm(my_df2)

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> end of section 1

#############
# Plots: Bubble plot
# x = Position, Y = stability
# size of dots = OR
# col: stability
#############

#=================
# generate plot 1: DUET vs OR by position as geom_points
#=================  

my_ats = 20 # axis text size
my_als = 22 # axis label size

# Spelling Correction: made redundant as already corrected at the source

#PS_df$DUET_outcome[PS_df$DUET_outcome=='Stabilizing'] <- 'Stabilising'
#PS_df$DUET_outcome[PS_df$DUET_outcome=='Destabilizing'] <- 'Destabilising'

table(PS_df$DUET_outcome) ; sum(table(PS_df$DUET_outcome))

g = ggplot(PS_df, aes(x = factor(Position)
                   , y = ratioDUET))

p1 = g + 
  geom_point(aes(col = DUET_outcome
                 , size = OR)) +
  theme(axis.text.x = element_text(size = my_ats
                                   , angle = 90
                                   , hjust = 1
                                   , vjust = 0.4)
        , axis.text.y = element_text(size = my_ats
                                     , angle = 0
                                     , hjust = 1
                                     , vjust = 0)
        , axis.title.x = element_text(size = my_als)
        , axis.title.y = element_text(size = my_als) 
        , legend.text = element_text(size = my_als)
        , legend.title = element_text(size = my_als) ) +
  #, legend.key.size = unit(1, "cm")) +
  labs(title = ""
       , x = "Position"
       , y = "DUET(PS)"
       , size = "Odds Ratio"
       , colour = "DUET Outcome") +
  guides(colour = guide_legend(override.aes = list(size=4))) 

p1 

#=================
# generate plot 2: Lig vs OR by position as geom_points
#=================  
my_ats = 20 # axis text size
my_als = 22 # axis label size

# Spelling Correction: made redundant as already corrected at the source

#Lig_df$Lig_outcome[Lig_df$Lig_outcome=='Stabilizing'] <- 'Stabilising'
#Lig_df$Lig_outcome[Lig_df$Lig_outcome=='Destabilizing'] <- 'Destabilising'

table(Lig_df$Lig_outcome)

g = ggplot(Lig_df, aes(x = factor(Position)
                   , y = ratioPredAff))

p2 = g + 
  geom_point(aes(col = Lig_outcome
                   , size = OR))+
  theme(axis.text.x = element_text(size = my_ats
                                   , angle = 90
                                   , hjust = 1
                                   , vjust = 0.4)
        , axis.text.y = element_text(size = my_ats
                                     , angle = 0
                                     , hjust = 1
                                     , vjust = 0)
        , axis.title.x = element_text(size = my_als)
        , axis.title.y = element_text(size = my_als) 
        , legend.text = element_text(size = my_als)
        , legend.title = element_text(size = my_als) ) +
  #, legend.key.size = unit(1, "cm")) +
  labs(title = ""
       , x = "Position"
       , y = "Ligand Affinity"
       , size = "Odds Ratio"
       , colour = "Ligand Outcome"
       ) +
  guides(colour = guide_legend(override.aes = list(size=4))) 

p2

#======================
#combine using cowplot
#======================
# set output dir for plots
getwd()
setwd("~/git/Data/pyrazinamide/output/plots")
getwd()

svg('PS_Lig_OR_combined.svg', width = 32, height = 12) #inches
#png('PS_Lig_OR_combined.png', width = 2800, height = 1080) #300dpi
theme_set(theme_gray()) # to preserve default theme

printFile = cowplot::plot_grid(plot_grid(p1, p2
                             , ncol = 1
                             , align = 'v'
                             , labels = c("(a)", "(b)")
                             , label_size = my_als+5))
print(printFile)
dev.off()

